{% load i18n %} {% load rich_text %} {% if schedule.comment %}

{{ schedule.comment|rich_text }}

{% elif schedule.changes.action == 'create' %}

{% translate "We released our first schedule!" %}

{% elif not schedule.changes.count %}

–

{% endif %} {% if schedule.changes.count %} {% if schedule.changes.new_talks|length > 0 %} {% if schedule.changes.new_talks|length > 1 %}

{% translate "We have new sessions!" %}

{% for talk in schedule.changes.new_talks %}
- {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talks.submission.speakers.exists %} {% translate "by" %} {{ talk.submission.display_speaker_names }} {% endif %}
{% endfor %}

{% else %}

{% translate "We have a new session: " %} {% for talk in schedule.changes.new_talks %} {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% translate "by" %} {{ talk.submission.display_speaker_names }} {% endif %} . {% endfor %} {% endif %}

{% endif %} {% if schedule.changes.canceled_talks|length > 0 %} {% if schedule.changes.canceled_talks|length > 1 %}

{% translate "Sadly, we had to cancel sessions:" %}

{% for talk in schedule.changes.canceled_talks %}
- {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% translate "by" %} {{ talk.submission.display_speaker_names }} {% endif %}
{% endfor %}

{% else %}

{% translate "We sadly had to cancel a session: " %} {% for talk in schedule.changes.canceled_talks %} {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% translate "by" %} {{ talk.submission.display_speaker_names }}. {% endif %} {% endfor %}

{% endif %} {% endif %} {% if schedule.changes.moved_talks|length > 0 %} {% if schedule.changes.moved_talks|length > 1 %}

{% translate "We had to move some sessions, so if you were planning on seeing them, check their new dates or locations:" %}

{% for talk in schedule.changes.moved_talks %}
- {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% translate "by" %} {{ talk.submission.display_speaker_names }} {% endif %} {% if talk.old_room == talk.new_room %} ({{ talk.old_start }} → {{ talk.new_start }}) {% elif talk.old_start == talk.new_start %} ({{ talk.old_room }} → {{ talk.new_room }}) {% else %} ({{ talk.old_start }}, {{ talk.old_room }} → {{ talk.new_start }}, {{ talk.new_room }}) {% endif %}
{% endfor %}

{% else %}

{% translate "We have moved a session around: " %} {% for talk in schedule.changes.moved_talks %} {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% translate "by" %} {{ talk.submission.display_speaker_names }} {% endif %} {% if talk.old_room == talk.new_room %} ({{ talk.old_start }} → {{ talk.new_start }}) {% elif talk.old_start == talk.new_start %} ({{ talk.old_room }} → {{ talk.new_room }}) {% else %} ({{ talk.old_start }}, {{ talk.old_room }} → {{ talk.new_start }}, {{ talk.new_room }}). {% endif %} {% endfor %}

{% endif %} {% endif %} {% endif %}